@@ -1,14 +1,13 @@
-package MooseX::Types::LoadableClass;
-# git description: v0.012-13-gcdaf68a
-$MooseX::Types::LoadableClass::VERSION = '0.013';
+package MooseX::Types::LoadableClass; # git description: v0.015-8-g23151a4
 # ABSTRACT: ClassName type constraint with coercion to load the class.
 # KEYWORDS: moose types constraints class classes role roles module modules
 
+our $VERSION = '0.016';
+
 use strict;
 use warnings;
-use MooseX::Types -declare => [qw/ ClassName LoadableClass LoadableRole /];
+use MooseX::Types -declare => [qw/ LoadableClass LoadableRole /];
 use MooseX::Types::Moose qw(Str RoleName), ClassName => { -as => 'MooseClassName' };
-use Moose::Util::TypeConstraints;
 use Module::Runtime qw(is_module_name use_package_optimistically);
 use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
 
@@ -37,7 +36,6 @@ coerce LoadableRole, from Str, via { $_ };
 __PACKAGE__->type_storage->{ClassName}
     = __PACKAGE__->type_storage->{LoadableClass};
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -52,7 +50,7 @@ MooseX::Types::LoadableClass - ClassName type constraint with coercion to load t
 
 =head1 VERSION
 
-version 0.013
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -93,20 +91,24 @@ A normal class / package.
 
 Like C<LoadableClass>, except the loaded package must be a L<Moose::Role>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-LoadableClass>
+(or L<bug-MooseX-Types-LoadableClass@rt.cpan.org|mailto:bug-MooseX-Types-LoadableClass@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Tomas Doran <bobtfish@bobtfish.net>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Infinity Interactive, Inc.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Dagfinn Ilmari Mannsåker Florian Ragwitz Сергей Романов
+=for stopwords Karen Etheridge Dagfinn Ilmari Mannsåker Florian Ragwitz Graham Knop Gregory Oschwald Сергей Романов
 
 =over 4
 
@@ -124,8 +126,23 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
 Сергей Романов <sromanov@cpan.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2010 by Infinity Interactive, Inc.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
